#!/bin/sh
set -o errexit
set -o nounset

# Copy installed files from the system
cp --recursive /usr/share/games/play.it/games/45_adventure "$AUTOPKGTEST_TMP/games"

# Copy test scripts from the source tree
cp Makefile "$AUTOPKGTEST_TMP"

# Run the tests
cd "$AUTOPKGTEST_TMP"
make check

exit 0
